﻿using System;
using System.Collections.ObjectModel;
using System.Collections.Generic;
using System.ComponentModel;

namespace GridSample
{
    public class MyDataObject : INotifyPropertyChanged
    {
        #region Private members

        private DateTime _date;
        private string _string;
        private int _int;
        private bool _bool;
        private ObservableCollection<MyDataObject> _children;

        #endregion // Private members

        #region Public Properties

        public int Int
        {
            get
            {
                return this._int;
            }
            set
            {
                if (value != this._int)
                {
                    this._int = value;
                    RaisePropertyChanged("Int");
                }
            }
        }

        public DateTime Date
        {
            get
            {
                return this._date;
            }

            set
            {
                if (value != this._date)
                {
                    this._date = value;
                    RaisePropertyChanged("Date");
                }
            }
        }

        public string String
        {
            get
            {
                return this._string;
            }
            set
            {
                if (value != this._string)
                {
                    this._string = value;
                    RaisePropertyChanged("String");
                }
            }
        }

        public bool Bool
        {
            get
            {
                return this._bool;
            }
            set
            {
                if (value != this._bool)
                {
                    this._bool = value;
                    RaisePropertyChanged("Bool");
                }
            }
        }

        public ObservableCollection<MyDataObject> Children
        {
            get
            {
                return this._children;
            }
            set
            {
                if (value != this._children)
                {
                    this._children = value;
                    RaisePropertyChanged("Children");
                }
            }
        }

        #endregion // Public Properties

        #region Constructors

        public MyDataObject(int index)
        {
            this.Int = index / 2;
            this.String = "Item " + index;
            this.Children = new ObservableCollection<MyDataObject>();
        }

        public MyDataObject()
        {
            
        }

        #endregion // Constructors

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        private void RaisePropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null)
            {
                this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion // INotifyPropertyChanged Members
    }

    public class MyData : ObservableCollection<MyDataObject>
    {
        public MyData()
        {
            FillDataCollection(this, 10);

            foreach (var item in this)
            {
                FillDataCollection(item.Children, 10);
            }
        }

        public static void FillDataCollection(IList<MyDataObject> collection, int rowCount)
        {
            for (int i = 0; i < rowCount; i++)
            {
                collection.Add(new MyDataObject(i)
                {
                    String = "Item " + i
                });
            }
        }
    }
}
